"""
backend_agent_output automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent
from .backend_agent_content_binary import BackendAgentContentBinary
from .backend_agent_content_choice import BackendAgentContentChoice
from .backend_agent_content_object import BackendAgentContentObject
from .backend_agent_content_text import BackendAgentContentText
from .backend_agent_content_tool_call import BackendAgentContentToolCall


# This object represents an agent output
class BackendAgentOutput(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    output: Annotated[Union["BackendAgentContentBinary", "BackendAgentContentChoice", "BackendAgentContentObject", "BackendAgentContentText", "BackendAgentContentToolCall"], Field(discriminator="type")] = Field(alias="output")
    pass





"""
consumer_user_password_reset automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerUserPasswordReset(BaseModel):
    token: Optional[str] = Field(default=None, alias="token")
    new_password: Optional[str] = Field(default=None, alias="newPassword")
    pass





"""
backend_agent_content_tool_call automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent
from .backend_agent_content_tool_call_function import BackendAgentContentToolCallFunction


# Tool call agent message
class BackendAgentContentToolCall(BackendAgentContent):
    type: Literal["tool_call"] = Field(alias="type")
    functions: Optional[List[BackendAgentContentToolCallFunction]] = Field(default=None, alias="functions")
    pass





"""
backend_test automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_test_config import BackendTestConfig


# This object represents a test. A test helps to verify that all operations work as expected
class BackendTest(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    operation_name: Optional[str] = Field(default=None, alias="operationName")
    message: Optional[str] = Field(default=None, alias="message")
    response: Optional[str] = Field(default=None, alias="response")
    config: Optional[BackendTestConfig] = Field(default=None, alias="config")
    pass





"""
backend_agent automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .common_metadata import CommonMetadata


# This object represents an agent
class BackendAgent(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    connection: Optional[int] = Field(default=None, alias="connection")
    type: Optional[int] = Field(default=None, alias="type")
    name: Optional[str] = Field(default=None, alias="name")
    description: Optional[str] = Field(default=None, alias="description")
    introduction: Optional[str] = Field(default=None, alias="introduction")
    tools: Optional[List[str]] = Field(default=None, alias="tools")
    outgoing: Optional[str] = Field(default=None, alias="outgoing")
    action: Optional[str] = Field(default=None, alias="action")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
BackendLogTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_log import BackendLog
from .backend_log_collection import BackendLogCollection
from .backend_log_error import BackendLogError
from .backend_log_error_collection import BackendLogErrorCollection
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendLogTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get(self, log_id: str) -> BackendLog:
        """
        Returns a specific log
        """
        try:
            path_params = {}
            path_params['log_id'] = log_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/log/$log_id<[0-9]+>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendLog.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendLogCollection:
        """
        Returns a paginated list of logs
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/log', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendLogCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all_errors(self, start_index: int, count: int, search: str) -> BackendLogErrorCollection:
        """
        Returns a paginated list of log errors
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search

            query_struct_names = []

            url = self.parser.url('/backend/log/error', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendLogErrorCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_error(self, error_id: str) -> BackendLogError:
        """
        Returns a specific error
        """
        try:
            path_params = {}
            path_params['error_id'] = error_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/log/error/$error_id<[0-9]+>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendLogError.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
BackendFormTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_form import BackendForm
from .backend_form_collection import BackendFormCollection
from .backend_form_create import BackendFormCreate
from .backend_form_update import BackendFormUpdate
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendFormTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def create(self, payload: BackendFormCreate) -> CommonMessage:
        """
        Creates a new form
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/form', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def delete(self, form_id: str) -> CommonMessage:
        """
        Deletes an existing form
        """
        try:
            path_params = {}
            path_params['form_id'] = form_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/form/$form_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('DELETE', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get(self, form_id: str) -> BackendForm:
        """
        Returns a specific form
        """
        try:
            path_params = {}
            path_params['form_id'] = form_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/form/$form_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendForm.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, start_index: int, count: int, search: str) -> BackendFormCollection:
        """
        Returns a paginated list of forms
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search

            query_struct_names = []

            url = self.parser.url('/backend/form', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendFormCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def update(self, form_id: str, payload: BackendFormUpdate) -> CommonMessage:
        """
        Updates an existing form
        """
        try:
            path_params = {}
            path_params['form_id'] = form_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/form/$form_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
SystemMetaTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .common_message import CommonMessage
from .common_message_exception import CommonMessageException
from .passthru import Passthru
from .system_about import SystemAbout
from .system_health_check import SystemHealthCheck
from .system_route import SystemRoute
from .system_schema import SystemSchema

class SystemMetaTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get_about(self) -> SystemAbout:
        """
        Returns meta information and links about the current installed Fusio version
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/system/about', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = SystemAbout.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_debug(self, payload: Passthru) -> Passthru:
        """
        Debug endpoint which returns the provided data
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/system/debug', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = Passthru.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_health(self) -> SystemHealthCheck:
        """
        Health check endpoint which returns information about the health status of the system
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/system/health', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = SystemHealthCheck.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_routes(self) -> SystemRoute:
        """
        Returns all available routes
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/system/route', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = SystemRoute.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_schema(self, name: str) -> SystemSchema:
        """
        Returns details of a specific schema
        """
        try:
            path_params = {}
            path_params['name'] = name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/system/schema/:name', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = SystemSchema.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_dashboard automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_statistic_chart import BackendStatisticChart


# Represents an object containing all widget data for the dashboard
class BackendDashboard(BaseModel):
    errors_per_operation: Optional[BackendStatisticChart] = Field(default=None, alias="errorsPerOperation")
    incoming_requests: Optional[BackendStatisticChart] = Field(default=None, alias="incomingRequests")
    incoming_transactions: Optional[BackendStatisticChart] = Field(default=None, alias="incomingTransactions")
    most_used_operations: Optional[BackendStatisticChart] = Field(default=None, alias="mostUsedOperations")
    time_per_operation: Optional[BackendStatisticChart] = Field(default=None, alias="timePerOperation")
    test_coverage: Optional[BackendStatisticChart] = Field(default=None, alias="testCoverage")
    most_used_activities: Optional[BackendStatisticChart] = Field(default=None, alias="mostUsedActivities")
    activities_per_user: Optional[BackendStatisticChart] = Field(default=None, alias="activitiesPerUser")
    user_registrations: Optional[BackendStatisticChart] = Field(default=None, alias="userRegistrations")
    pass





"""
BackendMarketplaceAppTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .common_message import CommonMessage
from .common_message_exception import CommonMessageException
from .marketplace_app import MarketplaceApp
from .marketplace_app_collection import MarketplaceAppCollection
from .marketplace_install import MarketplaceInstall
from .marketplace_message import MarketplaceMessage

class BackendMarketplaceAppTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get(self, user: str, name: str) -> MarketplaceApp:
        """
        Returns a specific marketplace app
        """
        try:
            path_params = {}
            path_params['user'] = user
            path_params['name'] = name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/marketplace/app/:user/:name', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = MarketplaceApp.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, start_index: int, query: str) -> MarketplaceAppCollection:
        """
        Returns a paginated list of marketplace apps
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['query'] = query

            query_struct_names = []

            url = self.parser.url('/backend/marketplace/app', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = MarketplaceAppCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def install(self, payload: MarketplaceInstall) -> MarketplaceMessage:
        """
        Installs an app from the marketplace
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/marketplace/app', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = MarketplaceMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def upgrade(self, user: str, name: str) -> MarketplaceMessage:
        """
        Upgrades an app from the marketplace
        """
        try:
            path_params = {}
            path_params['user'] = user
            path_params['name'] = name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/marketplace/app/:user/:name', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = MarketplaceMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_page automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_metadata import CommonMetadata


# This object represents a page at the developer portal
class BackendPage(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    title: Optional[str] = Field(default=None, alias="title")
    slug: Optional[str] = Field(default=None, alias="slug")
    content: Optional[str] = Field(default=None, alias="content")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
backend_file automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime


# This object represents a file on the filesystem
class BackendFile(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    content_type: Optional[str] = Field(default=None, alias="contentType")
    checksum: Optional[str] = Field(default=None, alias="checksum")
    last_modified: Optional[datetime.datetime] = Field(default=None, alias="lastModified")
    pass





"""
backend_taxonomy_move automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# Moves the provided objects to a taxonomy
class BackendTaxonomyMove(BaseModel):
    operations: Optional[List[int]] = Field(default=None, alias="operations")
    actions: Optional[List[int]] = Field(default=None, alias="actions")
    events: Optional[List[int]] = Field(default=None, alias="events")
    cronjobs: Optional[List[int]] = Field(default=None, alias="cronjobs")
    triggers: Optional[List[int]] = Field(default=None, alias="triggers")
    pass





"""
backend_agent_message_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_collection import CommonCollection
from .backend_agent_message import BackendAgentMessage


# Represents a collection of agent messages
class BackendAgentMessageCollection(CommonCollection[BackendAgentMessage]):
    pass





"""
backend_agent_content_choice automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent
from .backend_agent_content_binary import BackendAgentContentBinary
from .backend_agent_content_object import BackendAgentContentObject
from .backend_agent_content_text import BackendAgentContentText
from .backend_agent_content_tool_call import BackendAgentContentToolCall


# Choice agent message
class BackendAgentContentChoice(BackendAgentContent):
    type: Literal["choice"] = Field(alias="type")
    items: List[Annotated[Union["BackendAgentContentBinary", "BackendAgentContentChoice", "BackendAgentContentObject", "BackendAgentContentText", "BackendAgentContentToolCall"], Field(discriminator="type")]] = Field(alias="items")
    pass





"""
backend_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_operation_parameters import BackendOperationParameters
from .backend_operation_throws import BackendOperationThrows
from .common_metadata import CommonMetadata


# This object represents an operation, an operation invokes an action in case a specific HTTP method and path was requested. It defines also schema information about the request and response payload
class BackendOperation(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    active: Optional[bool] = Field(default=None, alias="active")
    public: Optional[bool] = Field(default=None, alias="public")
    stability: Optional[int] = Field(default=None, alias="stability")
    description: Optional[str] = Field(default=None, alias="description")
    http_method: Optional[str] = Field(default=None, alias="httpMethod")
    http_path: Optional[str] = Field(default=None, alias="httpPath")
    http_code: Optional[int] = Field(default=None, alias="httpCode")
    name: Optional[str] = Field(default=None, alias="name")
    parameters: Optional[BackendOperationParameters] = Field(default=None, alias="parameters")
    incoming: Optional[str] = Field(default=None, alias="incoming")
    outgoing: Optional[str] = Field(default=None, alias="outgoing")
    throws: Optional[BackendOperationThrows] = Field(default=None, alias="throws")
    action: Optional[str] = Field(default=None, alias="action")
    costs: Optional[int] = Field(default=None, alias="costs")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
backend_http_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a HTTP request
class BackendHttpRequest(BaseModel):
    method: Optional[str] = Field(default=None, alias="method")
    uri: Optional[str] = Field(default=None, alias="uri")
    headers: Optional[Dict[str, str]] = Field(default=None, alias="headers")
    body: Optional[str] = Field(default=None, alias="body")
    pass





"""
ConsumerTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .consumer_account_tag import ConsumerAccountTag
from .consumer_app_tag import ConsumerAppTag
from .consumer_event_tag import ConsumerEventTag
from .consumer_form_tag import ConsumerFormTag
from .consumer_grant_tag import ConsumerGrantTag
from .consumer_identity_tag import ConsumerIdentityTag
from .consumer_log_tag import ConsumerLogTag
from .consumer_page_tag import ConsumerPageTag
from .consumer_payment_tag import ConsumerPaymentTag
from .consumer_plan_tag import ConsumerPlanTag
from .consumer_scope_tag import ConsumerScopeTag
from .consumer_token_tag import ConsumerTokenTag
from .consumer_transaction_tag import ConsumerTransactionTag
from .consumer_webhook_tag import ConsumerWebhookTag

class ConsumerTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def account(self) -> ConsumerAccountTag:
        return ConsumerAccountTag(
            self.http_client,
            self.parser
        )

    def app(self) -> ConsumerAppTag:
        return ConsumerAppTag(
            self.http_client,
            self.parser
        )

    def event(self) -> ConsumerEventTag:
        return ConsumerEventTag(
            self.http_client,
            self.parser
        )

    def form(self) -> ConsumerFormTag:
        return ConsumerFormTag(
            self.http_client,
            self.parser
        )

    def grant(self) -> ConsumerGrantTag:
        return ConsumerGrantTag(
            self.http_client,
            self.parser
        )

    def identity(self) -> ConsumerIdentityTag:
        return ConsumerIdentityTag(
            self.http_client,
            self.parser
        )

    def log(self) -> ConsumerLogTag:
        return ConsumerLogTag(
            self.http_client,
            self.parser
        )

    def page(self) -> ConsumerPageTag:
        return ConsumerPageTag(
            self.http_client,
            self.parser
        )

    def payment(self) -> ConsumerPaymentTag:
        return ConsumerPaymentTag(
            self.http_client,
            self.parser
        )

    def plan(self) -> ConsumerPlanTag:
        return ConsumerPlanTag(
            self.http_client,
            self.parser
        )

    def scope(self) -> ConsumerScopeTag:
        return ConsumerScopeTag(
            self.http_client,
            self.parser
        )

    def token(self) -> ConsumerTokenTag:
        return ConsumerTokenTag(
            self.http_client,
            self.parser
        )

    def transaction(self) -> ConsumerTransactionTag:
        return ConsumerTransactionTag(
            self.http_client,
            self.parser
        )

    def webhook(self) -> ConsumerWebhookTag:
        return ConsumerWebhookTag(
            self.http_client,
            self.parser
        )





"""
backend_scope_categories automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_scope_category import BackendScopeCategory


class BackendScopeCategories(BaseModel):
    categories: Optional[List[BackendScopeCategory]] = Field(default=None, alias="categories")
    pass





"""
common_form_element_tag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_form_element import CommonFormElement


# Form element which represents an input tag editor to enter comma-separated values
class CommonFormElementTag(CommonFormElement):
    type: Literal["http://fusio-project.org/ns/2015/form/tag"] = Field(alias="type")
    pass





"""
consumer_user_email automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerUserEmail(BaseModel):
    email: Optional[str] = Field(default=None, alias="email")
    captcha: Optional[str] = Field(default=None, alias="captcha")
    pass





"""
backend_firewall automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .common_metadata import CommonMetadata


# This object represents a firewall rule which blocks specific IP addresses
class BackendFirewall(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    type: Optional[int] = Field(default=None, alias="type")
    ip: Optional[str] = Field(default=None, alias="ip")
    expire: Optional[datetime.datetime] = Field(default=None, alias="expire")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
common_form_element automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# Form base element
class CommonFormElement(BaseModel):
    element: Optional[str] = Field(default=None, alias="element")
    name: Optional[str] = Field(default=None, alias="name")
    title: Optional[str] = Field(default=None, alias="title")
    help: Optional[str] = Field(default=None, alias="help")
    pass





"""
marketplace_bundle_trigger automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class MarketplaceBundleTrigger(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    event: Optional[str] = Field(default=None, alias="event")
    action: Optional[str] = Field(default=None, alias="action")
    pass





"""
BackendConnectionAgentTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_agent_input import BackendAgentInput
from .backend_agent_output import BackendAgentOutput
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendConnectionAgentTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def send(self, connection_id: str, payload: BackendAgentInput) -> BackendAgentOutput:
        """
        Sends a message to an agent
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/agent', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendAgentOutput.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_action_index_entry import BackendActionIndexEntry


# Contains all possible classes which can be used at an action as class
class BackendActionIndex(BaseModel):
    actions: Optional[List[BackendActionIndexEntry]] = Field(default=None, alias="actions")
    pass





"""
backend_database_table automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_database_table_column import BackendDatabaseTableColumn
from .backend_database_table_index import BackendDatabaseTableIndex
from .backend_database_table_foreign_key_constraint import BackendDatabaseTableForeignKeyConstraint


# This object represents a relational table on a database connection
class BackendDatabaseTable(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    columns: Optional[List[BackendDatabaseTableColumn]] = Field(default=None, alias="columns")
    primary_key: Optional[str] = Field(default=None, alias="primaryKey")
    indexes: Optional[List[BackendDatabaseTableIndex]] = Field(default=None, alias="indexes")
    foreign_keys: Optional[List[BackendDatabaseTableForeignKeyConstraint]] = Field(default=None, alias="foreignKeys")
    pass





"""
marketplace_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .marketplace_object import MarketplaceObject


class MarketplaceApp(MarketplaceObject):
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    download_url: Optional[str] = Field(default=None, alias="downloadUrl")
    hash: Optional[str] = Field(default=None, alias="hash")
    pass





"""
backend_scope_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class BackendScopeOperation(BaseModel):
    operation_id: Optional[int] = Field(default=None, alias="operationId")
    allow: Optional[bool] = Field(default=None, alias="allow")
    pass





"""
backend_rate_allocation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a rate allocation, in case a request matches it gets assigned to the attached rate
class BackendRateAllocation(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    operation_id: Optional[int] = Field(default=None, alias="operationId")
    user_id: Optional[int] = Field(default=None, alias="userId")
    plan_id: Optional[int] = Field(default=None, alias="planId")
    app_id: Optional[int] = Field(default=None, alias="appId")
    authenticated: Optional[bool] = Field(default=None, alias="authenticated")
    pass





"""
backend_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime


# This object represents a token, this an access token which was requested by a user
class BackendToken(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    ip: Optional[str] = Field(default=None, alias="ip")
    expire: Optional[datetime.datetime] = Field(default=None, alias="expire")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass





"""
backend_database_table_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a table index on a relational database
class BackendDatabaseTableIndex(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    unique: Optional[bool] = Field(default=None, alias="unique")
    columns: Optional[List[str]] = Field(default=None, alias="columns")
    pass





"""
marketplace_bundle_config automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .marketplace_bundle_action import MarketplaceBundleAction
from .marketplace_bundle_schema import MarketplaceBundleSchema
from .marketplace_bundle_event import MarketplaceBundleEvent
from .marketplace_bundle_cronjob import MarketplaceBundleCronjob
from .marketplace_bundle_trigger import MarketplaceBundleTrigger


class MarketplaceBundleConfig(BaseModel):
    actions: Optional[List[MarketplaceBundleAction]] = Field(default=None, alias="actions")
    schemas: Optional[List[MarketplaceBundleSchema]] = Field(default=None, alias="schemas")
    events: Optional[List[MarketplaceBundleEvent]] = Field(default=None, alias="events")
    cronjobs: Optional[List[MarketplaceBundleCronjob]] = Field(default=None, alias="cronjobs")
    triggers: Optional[List[MarketplaceBundleTrigger]] = Field(default=None, alias="triggers")
    pass





"""
ConsumerIdentityTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .common_message import CommonMessage
from .common_message_exception import CommonMessageException
from .consumer_identity_collection import ConsumerIdentityCollection
from .passthru import Passthru

class ConsumerIdentityTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def exchange(self, identity: str) -> Passthru:
        """
        Identity callback endpoint to exchange an access token
        """
        try:
            path_params = {}
            path_params['identity'] = identity

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/identity/:identity/exchange', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = Passthru.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, app_id: int, app_key: str) -> ConsumerIdentityCollection:
        """
        Returns a paginated list of identities which are relevant to the authenticated user
        """
        try:
            path_params = {}

            query_params = {}
            query_params['appId'] = app_id
            query_params['appKey'] = app_key

            query_struct_names = []

            url = self.parser.url('/consumer/identity', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerIdentityCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def redirect(self, identity: str) -> Passthru:
        """
        Redirect the user to the configured identity provider
        """
        try:
            path_params = {}
            path_params['identity'] = identity

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/identity/:identity/redirect', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = Passthru.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_generator_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_generator_provider_config import BackendGeneratorProviderConfig


class BackendGeneratorProvider(BaseModel):
    path: Optional[str] = Field(default=None, alias="path")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    public: Optional[bool] = Field(default=None, alias="public")
    config: Optional[BackendGeneratorProviderConfig] = Field(default=None, alias="config")
    pass





"""
BackendGeneratorTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_generator_index_providers import BackendGeneratorIndexProviders
from .backend_generator_provider import BackendGeneratorProvider
from .backend_generator_provider_changelog import BackendGeneratorProviderChangelog
from .backend_generator_provider_config import BackendGeneratorProviderConfig
from .common_form_container import CommonFormContainer
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendGeneratorTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def execute_provider(self, provider: str, payload: BackendGeneratorProvider) -> CommonMessage:
        """
        Executes a generator with the provided config
        """
        try:
            path_params = {}
            path_params['provider'] = provider

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/generator/:provider', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_changelog(self, provider: str, payload: BackendGeneratorProviderConfig) -> BackendGeneratorProviderChangelog:
        """
        Generates a changelog of all potential changes if you execute this generator with the provided config
        """
        try:
            path_params = {}
            path_params['provider'] = provider

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/generator/:provider', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendGeneratorProviderChangelog.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_classes(self) -> BackendGeneratorIndexProviders:
        """
        Returns all available generator classes
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/generator', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendGeneratorIndexProviders.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_form(self, provider: str) -> CommonFormContainer:
        """
        Returns the generator config form
        """
        try:
            path_params = {}
            path_params['provider'] = provider

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/generator/:provider', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonFormContainer.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_agent_content_object automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent


# Structured agent message
class BackendAgentContentObject(BackendAgentContent):
    type: Literal["object"] = Field(alias="type")
    payload: Optional[Any] = Field(default=None, alias="payload")
    pass





"""
backend_schema_commit automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .backend_user import BackendUser
from .backend_schema_source import BackendSchemaSource


# A schema commit which represents a change in the schema source
class BackendSchemaCommit(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    user: Optional[BackendUser] = Field(default=None, alias="user")
    commit_hash: Optional[str] = Field(default=None, alias="commitHash")
    schema_: Optional[BackendSchemaSource] = Field(default=None, alias="schema")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass





"""
marketplace_object automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .marketplace_user import MarketplaceUser


# Base class of all objects on the marketplace
class MarketplaceObject(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    author: Optional[MarketplaceUser] = Field(default=None, alias="author")
    version: Optional[str] = Field(default=None, alias="version")
    icon: Optional[str] = Field(default=None, alias="icon")
    summary: Optional[str] = Field(default=None, alias="summary")
    description: Optional[str] = Field(default=None, alias="description")
    cost: Optional[int] = Field(default=None, alias="cost")
    update_date: Optional[datetime.datetime] = Field(default=None, alias="updateDate")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass





"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerAuthorizeResponse(BaseModel):
    type: Optional[str] = Field(default=None, alias="type")
    code: Optional[str] = Field(default=None, alias="code")
    error: Optional[str] = Field(default=None, alias="error")
    state: Optional[str] = Field(default=None, alias="state")
    redirect_uri: Optional[str] = Field(default=None, alias="redirectUri")
    pass





"""
BackendConnectionDatabaseTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_database_row import BackendDatabaseRow
from .backend_database_row_collection import BackendDatabaseRowCollection
from .backend_database_table import BackendDatabaseTable
from .backend_database_table_collection import BackendDatabaseTableCollection
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendConnectionDatabaseTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def create_row(self, connection_id: str, table_name: str, payload: BackendDatabaseRow) -> CommonMessage:
        """
        Creates a new row at a table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name/rows', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def create_table(self, connection_id: str, payload: BackendDatabaseTable) -> CommonMessage:
        """
        Creates a new table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def delete_row(self, connection_id: str, table_name: str, id: str) -> CommonMessage:
        """
        Deletes an existing row at a table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name
            path_params['id'] = id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name/rows/:id', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('DELETE', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def delete_table(self, connection_id: str, table_name: str) -> CommonMessage:
        """
        Deletes an existing table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('DELETE', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_row(self, connection_id: str, table_name: str, id: str) -> BackendDatabaseRow:
        """
        Returns a specific row at a table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name
            path_params['id'] = id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name/rows/:id', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendDatabaseRow.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_rows(self, connection_id: str, table_name: str, start_index: int, count: int, filter_by: str, filter_op: str, filter_value: str, sort_by: str, sort_order: str, columns: str) -> BackendDatabaseRowCollection:
        """
        Returns paginated rows at a table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['filterBy'] = filter_by
            query_params['filterOp'] = filter_op
            query_params['filterValue'] = filter_value
            query_params['sortBy'] = sort_by
            query_params['sortOrder'] = sort_order
            query_params['columns'] = columns

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name/rows', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendDatabaseRowCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_table(self, connection_id: str, table_name: str) -> BackendDatabaseTable:
        """
        Returns the schema of a specific table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendDatabaseTable.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_tables(self, connection_id: str, start_index: int, count: int) -> BackendDatabaseTableCollection:
        """
        Returns all available tables on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendDatabaseTableCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def update_row(self, connection_id: str, table_name: str, id: str, payload: BackendDatabaseRow) -> CommonMessage:
        """
        Updates an existing row at a table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name
            path_params['id'] = id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name/rows/:id', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def update_table(self, connection_id: str, table_name: str, payload: BackendDatabaseTable) -> CommonMessage:
        """
        Updates an existing table on a database
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['table_name'] = table_name

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/database/:table_name', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
common_form_element_select automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_form_element import CommonFormElement
from .common_form_element_select_option import CommonFormElementSelectOption


# Form element which represents a select element
class CommonFormElementSelect(CommonFormElement):
    type: Literal["http://fusio-project.org/ns/2015/form/select"] = Field(alias="type")
    options: Optional[List[CommonFormElementSelectOption]] = Field(default=None, alias="options")
    pass





"""
backend_test_config automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_action_execute_request import BackendActionExecuteRequest


class BackendTestConfig(BackendActionExecuteRequest):
    pass





"""
backend_generator_provider_changelog automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_schema import BackendSchema
from .backend_action import BackendAction
from .backend_operation import BackendOperation


class BackendGeneratorProviderChangelog(BaseModel):
    schemas: Optional[List[BackendSchema]] = Field(default=None, alias="schemas")
    actions: Optional[List[BackendAction]] = Field(default=None, alias="actions")
    operations: Optional[List[BackendOperation]] = Field(default=None, alias="operations")
    pass





"""
backend_agent_content_binary automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent


# Binary agent message
class BackendAgentContentBinary(BackendAgentContent):
    type: Literal["binary"] = Field(alias="type")
    mime: Optional[str] = Field(default=None, alias="mime")
    data: Optional[str] = Field(default=None, alias="data")
    pass





"""
common_form_container automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_form_element import CommonFormElement
from .common_form_element_input import CommonFormElementInput
from .common_form_element_select import CommonFormElementSelect
from .common_form_element_tag import CommonFormElementTag
from .common_form_element_text_area import CommonFormElementTextArea


# Represents a config form with a list of elements
class CommonFormContainer(BaseModel):
    element: List[Annotated[Union["CommonFormElementInput", "CommonFormElementSelect", "CommonFormElementTag", "CommonFormElementTextArea"], Field(discriminator="type")]] = Field(alias="element")
    pass





"""
backend_log_error automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime


class BackendLogError(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    log_id: Optional[int] = Field(default=None, alias="logId")
    message: Optional[str] = Field(default=None, alias="message")
    trace: Optional[str] = Field(default=None, alias="trace")
    file: Optional[str] = Field(default=None, alias="file")
    line: Optional[int] = Field(default=None, alias="line")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass





"""
backend_identity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_identity_config import BackendIdentityConfig


# This object represents an identity which allows to authenticate with a remote identity provider
class BackendIdentity(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app_id: Optional[int] = Field(default=None, alias="appId")
    role_id: Optional[int] = Field(default=None, alias="roleId")
    name: Optional[str] = Field(default=None, alias="name")
    icon: Optional[str] = Field(default=None, alias="icon")
    class_: Optional[str] = Field(default=None, alias="class")
    config: Optional[BackendIdentityConfig] = Field(default=None, alias="config")
    allow_create: Optional[bool] = Field(default=None, alias="allowCreate")
    pass





"""
BackendMarketplaceTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_marketplace_action_tag import BackendMarketplaceActionTag
from .backend_marketplace_app_tag import BackendMarketplaceAppTag
from .backend_marketplace_bundle_tag import BackendMarketplaceBundleTag

class BackendMarketplaceTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def action(self) -> BackendMarketplaceActionTag:
        return BackendMarketplaceActionTag(
            self.http_client,
            self.parser
        )

    def app(self) -> BackendMarketplaceAppTag:
        return BackendMarketplaceAppTag(
            self.http_client,
            self.parser
        )

    def bundle(self) -> BackendMarketplaceBundleTag:
        return BackendMarketplaceBundleTag(
            self.http_client,
            self.parser
        )





"""
consumer_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .consumer_webhook_response import ConsumerWebhookResponse


class ConsumerWebhook(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    event: Optional[str] = Field(default=None, alias="event")
    name: Optional[str] = Field(default=None, alias="name")
    endpoint: Optional[str] = Field(default=None, alias="endpoint")
    responses: Optional[List[ConsumerWebhookResponse]] = Field(default=None, alias="responses")
    pass





"""
backend_sdk_message automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class BackendSdkMessage(BaseModel):
    success: Optional[bool] = Field(default=None, alias="success")
    message: Optional[str] = Field(default=None, alias="message")
    link: Optional[str] = Field(default=None, alias="link")
    pass





"""
backend_agent_tools automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_tool import BackendAgentTool


# Represents a collection of available tools
class BackendAgentTools(BaseModel):
    tools: Optional[List[BackendAgentTool]] = Field(default=None, alias="tools")
    pass





"""
backend_database_table_foreign_key_constraint automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a foreign key constraint on a relational database
class BackendDatabaseTableForeignKeyConstraint(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    foreign_table: Optional[str] = Field(default=None, alias="foreignTable")
    local_column_names: Optional[List[str]] = Field(default=None, alias="localColumnNames")
    foreign_column_names: Optional[List[str]] = Field(default=None, alias="foreignColumnNames")
    pass





"""
consumer_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerWebhookResponse(BaseModel):
    status: Optional[int] = Field(default=None, alias="status")
    code: Optional[int] = Field(default=None, alias="code")
    attempts: Optional[str] = Field(default=None, alias="attempts")
    execute_date: Optional[str] = Field(default=None, alias="executeDate")
    pass





"""
BackendStatisticTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_statistic_chart import BackendStatisticChart
from .backend_statistic_count import BackendStatisticCount
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendStatisticTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get_activities_per_user(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the activities per user
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/activities_per_user', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_count_requests(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticCount:
        """
        Returns a statistic containing the request count
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/count_requests', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticCount.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_errors_per_operation(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the errors per operation
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/errors_per_operation', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_incoming_requests(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the incoming requests
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/incoming_requests', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_incoming_transactions(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the incoming transactions
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/incoming_transactions', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_issued_tokens(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the issues tokens
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/issued_tokens', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_most_used_activities(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the most used activities
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/most_used_activities', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_most_used_apps(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the most used apps
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/most_used_apps', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_most_used_operations(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the most used operations
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/most_used_operations', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_requests_per_ip(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the requests per ip
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/requests_per_ip', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_requests_per_operation(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the requests per operation
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/requests_per_operation', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_requests_per_user(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the requests per user
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/requests_per_user', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_test_coverage(self) -> BackendStatisticChart:
        """
        Returns a statistic containing the test coverage
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/statistic/test_coverage', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_time_average(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the time average
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/time_average', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_time_per_operation(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the time per operation
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/time_per_operation', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_used_points(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the used points
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/used_points', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_user_registrations(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        """
        Returns a statistic containing the user registrations
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['from'] = from_
            query_params['to'] = to
            query_params['operationId'] = operation_id
            query_params['appId'] = app_id
            query_params['userId'] = user_id
            query_params['ip'] = ip
            query_params['userAgent'] = user_agent
            query_params['method'] = method
            query_params['path'] = path
            query_params['header'] = header
            query_params['body'] = body

            query_struct_names = []

            url = self.parser.url('/backend/statistic/user_registrations', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendStatisticChart.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_agent_content automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# Agent message
class BackendAgentContent(BaseModel):
    type: str = Field(alias="type")
    metadata: Optional[Dict[str, Any]] = Field(default=None, alias="metadata")
    pass





"""
BackendConnectionTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_connection import BackendConnection
from .backend_connection_agent_tag import BackendConnectionAgentTag
from .backend_connection_collection import BackendConnectionCollection
from .backend_connection_create import BackendConnectionCreate
from .backend_connection_database_tag import BackendConnectionDatabaseTag
from .backend_connection_filesystem_tag import BackendConnectionFilesystemTag
from .backend_connection_http_tag import BackendConnectionHttpTag
from .backend_connection_index import BackendConnectionIndex
from .backend_connection_redirect_response import BackendConnectionRedirectResponse
from .backend_connection_sdk_tag import BackendConnectionSdkTag
from .backend_connection_update import BackendConnectionUpdate
from .common_form_container import CommonFormContainer
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendConnectionTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def agent(self) -> BackendConnectionAgentTag:
        return BackendConnectionAgentTag(
            self.http_client,
            self.parser
        )

    def database(self) -> BackendConnectionDatabaseTag:
        return BackendConnectionDatabaseTag(
            self.http_client,
            self.parser
        )

    def filesystem(self) -> BackendConnectionFilesystemTag:
        return BackendConnectionFilesystemTag(
            self.http_client,
            self.parser
        )

    def http(self) -> BackendConnectionHttpTag:
        return BackendConnectionHttpTag(
            self.http_client,
            self.parser
        )

    def sdk(self) -> BackendConnectionSdkTag:
        return BackendConnectionSdkTag(
            self.http_client,
            self.parser
        )


    def create(self, payload: BackendConnectionCreate) -> CommonMessage:
        """
        Creates a new connection
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def delete(self, connection_id: str) -> CommonMessage:
        """
        Deletes an existing connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/$connection_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('DELETE', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get(self, connection_id: str) -> BackendConnection:
        """
        Returns a specific connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/$connection_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendConnection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, start_index: int, count: int, search: str, class_: str) -> BackendConnectionCollection:
        """
        Returns a paginated list of connections
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search
            query_params['class'] = class_

            query_struct_names = []

            url = self.parser.url('/backend/connection', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendConnectionCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_classes(self) -> BackendConnectionIndex:
        """
        Returns all available connection classes
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/list', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendConnectionIndex.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_form(self, class_: str) -> CommonFormContainer:
        """
        Returns the connection config form
        """
        try:
            path_params = {}

            query_params = {}
            query_params['class'] = class_

            query_struct_names = []

            url = self.parser.url('/backend/connection/form', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonFormContainer.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_redirect(self, connection_id: str) -> BackendConnectionRedirectResponse:
        """
        Returns a redirect url to start the OAuth2 authorization flow for the given connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/redirect', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendConnectionRedirectResponse.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def update(self, connection_id: str, payload: BackendConnectionUpdate) -> CommonMessage:
        """
        Updates an existing connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/$connection_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
backend_bundle automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_bundle_config import BackendBundleConfig


# This object represents a bundle which contains action, schema, event, cronjob and trigger configurations from you local instance
class BackendBundle(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    version: Optional[str] = Field(default=None, alias="version")
    icon: Optional[str] = Field(default=None, alias="icon")
    summary: Optional[str] = Field(default=None, alias="summary")
    description: Optional[str] = Field(default=None, alias="description")
    cost: Optional[int] = Field(default=None, alias="cost")
    config: Optional[BackendBundleConfig] = Field(default=None, alias="config")
    pass





"""
backend_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_schema_source import BackendSchemaSource
from .common_metadata import CommonMetadata


# This object represents a schema to describe a JSON payload
class BackendSchema(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    source: Optional[BackendSchemaSource] = Field(default=None, alias="source")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass





"""
marketplace_action automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .marketplace_object import MarketplaceObject
from .marketplace_action_config import MarketplaceActionConfig


class MarketplaceAction(MarketplaceObject):
    class_: Optional[str] = Field(default=None, alias="class")
    config: Optional[MarketplaceActionConfig] = Field(default=None, alias="config")
    pass





"""
consumer_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .consumer_plan import ConsumerPlan


class ConsumerTransaction(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    user_id: Optional[int] = Field(default=None, alias="userId")
    plan_id: Optional[int] = Field(default=None, alias="planId")
    plan: Optional[ConsumerPlan] = Field(default=None, alias="plan")
    transaction_id: Optional[str] = Field(default=None, alias="transactionId")
    amount: Optional[float] = Field(default=None, alias="amount")
    points: Optional[float] = Field(default=None, alias="points")
    period_start: Optional[datetime.datetime] = Field(default=None, alias="periodStart")
    period_end: Optional[datetime.datetime] = Field(default=None, alias="periodEnd")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass





"""
consumer_token_access_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerTokenAccessToken(BaseModel):
    access_token: Optional[str] = Field(default=None, alias="access_token")
    token_type: Optional[str] = Field(default=None, alias="token_type")
    expires_in: Optional[int] = Field(default=None, alias="expires_in")
    refresh_token: Optional[str] = Field(default=None, alias="refresh_token")
    scope: Optional[str] = Field(default=None, alias="scope")
    pass





"""
ConsumerTransactionTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .common_message import CommonMessage
from .common_message_exception import CommonMessageException
from .consumer_transaction import ConsumerTransaction
from .consumer_transaction_collection import ConsumerTransactionCollection

class ConsumerTransactionTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get(self, transaction_id: str) -> ConsumerTransaction:
        """
        Returns a specific transaction for the authenticated user
        """
        try:
            path_params = {}
            path_params['transaction_id'] = transaction_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/transaction/$transaction_id<[0-9]+|^~>', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerTransaction.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, start_index: int, count: int, search: str) -> ConsumerTransactionCollection:
        """
        Returns a paginated list of transactions which are assigned to the authenticated user
        """
        try:
            path_params = {}

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count
            query_params['search'] = search

            query_struct_names = []

            url = self.parser.url('/consumer/transaction', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerTransactionCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
ConsumerAccountTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_account_change_password import BackendAccountChangePassword
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException
from .consumer_authorize_meta import ConsumerAuthorizeMeta
from .consumer_authorize_request import ConsumerAuthorizeRequest
from .consumer_authorize_response import ConsumerAuthorizeResponse
from .consumer_user_account import ConsumerUserAccount
from .consumer_user_activate import ConsumerUserActivate
from .consumer_user_email import ConsumerUserEmail
from .consumer_user_jwt import ConsumerUserJWT
from .consumer_user_login import ConsumerUserLogin
from .consumer_user_password_reset import ConsumerUserPasswordReset
from .consumer_user_refresh import ConsumerUserRefresh
from .consumer_user_register import ConsumerUserRegister

class ConsumerAccountTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def activate(self, payload: ConsumerUserActivate) -> CommonMessage:
        """
        Activates an previously registered account through a token which was provided to the user via email
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/activate', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def authorize(self, payload: ConsumerAuthorizeRequest) -> ConsumerAuthorizeResponse:
        """
        Authorizes the access of a specific app for the authenticated user
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/authorize', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerAuthorizeResponse.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def change_password(self, payload: BackendAccountChangePassword) -> CommonMessage:
        """
        Change the password for the authenticated user
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/account/change_password', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def execute_password_reset(self, payload: ConsumerUserPasswordReset) -> CommonMessage:
        """
        Change the password after the password reset flow was started
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/password_reset', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get(self) -> ConsumerUserAccount:
        """
        Returns a user data for the authenticated user
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/account', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerUserAccount.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_app(self, client_id: str, scope: str) -> ConsumerAuthorizeMeta:
        """
        Returns information about a specific app to start the OAuth2 authorization code flow
        """
        try:
            path_params = {}

            query_params = {}
            query_params['client_id'] = client_id
            query_params['scope'] = scope

            query_struct_names = []

            url = self.parser.url('/consumer/authorize', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerAuthorizeMeta.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def login(self, payload: ConsumerUserLogin) -> ConsumerUserJWT:
        """
        User login by providing a username and password
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/login', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerUserJWT.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def refresh(self, payload: ConsumerUserRefresh) -> ConsumerUserJWT:
        """
        Refresh a previously obtained access token
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/login', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = ConsumerUserJWT.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def register(self, payload: ConsumerUserRegister) -> CommonMessage:
        """
        Register a new user account
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/register', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def request_password_reset(self, payload: ConsumerUserEmail) -> CommonMessage:
        """
        Start the password reset flow
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/password_reset', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def update(self, payload: ConsumerUserAccount) -> CommonMessage:
        """
        Updates user data for the authenticated user
        """
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/consumer/account', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
BackendConnectionFilesystemTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_file_collection import BackendFileCollection
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendConnectionFilesystemTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def create(self, connection_id: str, payload: Dict[str, Any]) -> CommonMessage:
        """
        Uploads one or more files on the filesystem connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/filesystem', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['files'] = payload


            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def delete(self, connection_id: str, file_id: str) -> CommonMessage:
        """
        Deletes an existing file on the filesystem connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['file_id'] = file_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/filesystem/:file_id', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('DELETE', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get(self, connection_id: str, file_id: str) -> bytearray:
        """
        Returns the content of the provided file id on the filesystem connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['file_id'] = file_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/filesystem/:file_id', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)


            options['headers']['Accept'] = 'application/octet-stream'

            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = response.content

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def get_all(self, connection_id: str, start_index: int, count: int) -> BackendFileCollection:
        """
        Returns all available files on the filesystem connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}
            query_params['startIndex'] = start_index
            query_params['count'] = count

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/filesystem', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)



            response = self.http_client.request('GET', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendFileCollection.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))

    def update(self, connection_id: str, file_id: str, payload: Dict[str, Any]) -> CommonMessage:
        """
        Updates an existing file on the filesystem connection
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id
            path_params['file_id'] = file_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/filesystem/:file_id', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['files'] = payload


            response = self.http_client.request('PUT', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = CommonMessage.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))






"""
Client automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .authorization_tag import AuthorizationTag
from .backend_tag import BackendTag
from .consumer_tag import ConsumerTag
from .system_tag import SystemTag

class Client(sdkgen.ClientAbstract):
    def __init__(self, base_url: str, credentials: sdkgen.CredentialsInterface):
        super().__init__(base_url, credentials)

    def authorization(self) -> AuthorizationTag:
        return AuthorizationTag(
            self.http_client,
            self.parser
        )

    def backend(self) -> BackendTag:
        return BackendTag(
            self.http_client,
            self.parser
        )

    def consumer(self) -> ConsumerTag:
        return ConsumerTag(
            self.http_client,
            self.parser
        )

    def system(self) -> SystemTag:
        return SystemTag(
            self.http_client,
            self.parser
        )




    @staticmethod
    def buildAnonymous(baseUrl: str):
        return Client(baseUrl, sdkgen.Anonymous())
